@@ -1,5 +1,6 @@
 /*
- * Copyright © 2015-2016 Canonical Ltd.
+ * Copyright 2015-2016 Canonical Ltd.
+ * Copyright 2021 Robert Tari
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,6 +17,7 @@
  * Authors:
  *      Ted Gould <ted@canonical.com>
  *      Charles Kerr <charles.kerr@canonical.com>
+ *      Robert Tari <robert@tari.in>
  */
 
 #include <algorithm>
@@ -425,7 +427,7 @@ TEST_F(NotificationsTest, DISABLED_HighVolume) {
     ASSERT_EQ(1, notev.size());
     EXPECT_EQ("Volume", notev[0].summary);
     EXPECT_EQ("Speakers", notev[0].body);
-    EXPECT_GVARIANT_EQ("@s 'false'", notev[0].hints["x-canonical-value-bar-tint"]);
+    EXPECT_GVARIANT_EQ("@s 'false'", notev[0].hints["x-lomiri-value-bar-tint"]);
 
     /* Set high volume with volume change */
     notifications->clearNotifications();
@@ -436,7 +438,7 @@ TEST_F(NotificationsTest, DISABLED_HighVolume) {
     ASSERT_LT(0, notev.size()); /* This passes with one or two since it would just be an update to the first if a second was sent */
     EXPECT_EQ("Volume", notev[0].summary);
     EXPECT_EQ("Speakers", notev[0].body);
-    EXPECT_GVARIANT_EQ("@s 'true'", notev[0].hints["x-canonical-value-bar-tint"]);
+    EXPECT_GVARIANT_EQ("@s 'true'", notev[0].hints["x-lomiri-value-bar-tint"]);
 
     /* Move it back */
     volume_warning_mock_set_high_volume(VOLUME_WARNING_MOCK(volumeWarning.get()), false);
@@ -452,7 +454,7 @@ TEST_F(NotificationsTest, DISABLED_HighVolume) {
     ASSERT_EQ(1, notev.size());
     EXPECT_EQ("Volume", notev[0].summary);
     EXPECT_EQ("Speakers", notev[0].body);
-    EXPECT_GVARIANT_EQ("@s 'true'", notev[0].hints["x-canonical-value-bar-tint"]);
+    EXPECT_GVARIANT_EQ("@s 'true'", notev[0].hints["x-lomiri-value-bar-tint"]);
 }
 
 TEST_F(NotificationsTest, DISABLED_MenuHide) {
@@ -619,13 +621,13 @@ TEST_F(NotificationsTest, DISABLED_TriggerWarning) {
         if (warning_expected) {
             EXPECT_TRUE(volume_warning_get_active(volumeWarning.get()));
             ASSERT_EQ(1, notev.size());
-            EXPECT_GVARIANT_EQ("@s 'true'", notev[0].hints["x-ayatana-snap-decisions"]);
+            EXPECT_GVARIANT_EQ("@s 'true'", notev[0].hints["x-lomiri-snap-decisions"]);
             EXPECT_GVARIANT_EQ(nullptr, notev[0].hints["x-canonical-private-synchronous"]);
         }
         else {
             EXPECT_FALSE(volume_warning_get_active(volumeWarning.get()));
             ASSERT_EQ(1, notev.size());
-            EXPECT_GVARIANT_EQ(nullptr, notev[0].hints["x-ayatana-snap-decisions"]);
+            EXPECT_GVARIANT_EQ(nullptr, notev[0].hints["x-lomiri-snap-decisions"]);
             EXPECT_GVARIANT_EQ("@s 'true'", notev[0].hints["x-canonical-private-synchronous"]);
         }
 
